QsRichLabel class

支持局部样式、点击事件和文字描边的富文本标签。

Inheritance

Constructors

QsRichLabel({Key? key, required String text, TextStyle? baseStyle, TextAlign textAlign = TextAlign.left, Map<String, QsRichLabelStyle>? matchedStrings, int? maxLines, TextOverflow? overflow, double borderWidth = 0, Color? borderColor})
创建一个富文本标签。
const

Properties

baseStyle TextStyle?
未匹配文字使用的基础样式。
final
borderColor Color?
文字描边颜色,为 null 时不绘制描边。
final
borderWidth double
文字描边宽度,小于或等于零时不绘制描边。
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
matchedStrings Map<String, QsRichLabelStyle>?
待匹配文字与对应样式的映射。
final
maxLines int?
最大显示行数。
final
overflow TextOverflow?
文字超出可用空间时的处理方式。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
需要显示的完整文本。
final
textAlign TextAlign
文本的水平对齐方式。
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited