QsRichLabelStyle class

富文本匹配样式

Constructors

QsRichLabelStyle({Color? color, FontWeight? fontWeight, double? fontSize, String? fontFamily, bool ignoreCase = false, TextDecoration decoration = TextDecoration.none, TextDecorationStyle decorationStyle = TextDecorationStyle.solid, Color? decorationColor, VoidCallback? onTap})
创建一组富文本匹配样式。
const

Properties

color Color?
匹配文字的颜色。
final
decoration TextDecoration
匹配文字的装饰线类型。
final
decorationColor Color?
匹配文字的装饰线颜色。
final
decorationStyle TextDecorationStyle
匹配文字的装饰线样式。
final
fontFamily String?
匹配文字使用的字体族名称。
final
fontSize double?
匹配文字的大小。
final
fontWeight FontWeight?
匹配文字的粗细。
final
hashCode int
The hash code for this object.
no setterinherited
ignoreCase bool
匹配文字时是否忽略大小写。
final
onTap VoidCallback?
点击匹配文字时的回调。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

apply(TextStyle? baseStyle) TextStyle
将当前配置合并到 baseStyle 并生成最终文字样式。
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited