QsSwitchButton class

固定使用白色滑块且不显示轨道轮廓的开关组件。

Inheritance

Constructors

QsSwitchButton({Key? key, required bool value, required ValueChanged<bool>? onChanged, required Color activeTrackColor, required Color inactiveTrackColor, ImageProvider<Object>? activeThumbImage, ImageErrorListener? onActiveThumbImageError, ImageProvider<Object>? inactiveThumbImage, ImageErrorListener? onInactiveThumbImageError, WidgetStateProperty<Color?>? thumbColor, WidgetStateProperty<Color?>? trackColor, WidgetStateProperty<double?>? trackOutlineWidth, WidgetStateProperty<Icon?>? thumbIcon, MaterialTapTargetSize? materialTapTargetSize, DragStartBehavior dragStartBehavior = DragStartBehavior.start, MouseCursor? mouseCursor, Color? focusColor, Color? hoverColor, WidgetStateProperty<Color?>? overlayColor, double? splashRadius, FocusNode? focusNode, ValueChanged<bool>? onFocusChange, bool autofocus = false, EdgeInsetsGeometry? padding})
创建一个自定义开关。

Properties

activeColor Color?
The color to use when this switch is on.
finalinherited
activeThumbColor Color?
The color to use when this switch is on.
finalinherited
activeThumbImage ImageProvider<Object>?
An image to use on the thumb of this switch when the switch is on.
finalinherited
activeTrackColor Color?
The color to use on the track when this switch is on.
finalinherited
applyCupertinoTheme bool?
Whether to apply the ambient CupertinoThemeData.
finalinherited
autofocus bool
True if this widget will be selected as the initial focus when no other node in its scope is currently focused.
finalinherited
dragStartBehavior DragStartBehavior
Determines the way that drag start behavior is handled.
finalinherited
focusColor Color?
The color for the button's Material when it has the input focus.
finalinherited
focusNode FocusNode?
An optional focus node to use as the focus node for this widget.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
hoverColor Color?
The color for the button's Material when a pointer is hovering over it.
finalinherited
inactiveThumbColor Color?
The color to use on the thumb when this switch is off.
finalinherited
inactiveThumbImage ImageProvider<Object>?
An image to use on the thumb of this switch when the switch is off.
finalinherited
inactiveTrackColor Color?
The color to use on the track when this switch is off.
finalinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
materialTapTargetSize MaterialTapTargetSize?
Configures the minimum size of the tap target.
finalinherited
mouseCursor MouseCursor?
The cursor for a mouse pointer when it enters or is hovering over the widget.
finalinherited
onActiveThumbImageError ImageErrorListener?
An optional error callback for errors emitted when loading activeThumbImage.
finalinherited
onChanged ValueChanged<bool>?
Called when the user toggles the switch on or off.
finalinherited
onFocusChange ValueChanged<bool>?
Handler called when the focus changes.
finalinherited
onInactiveThumbImageError ImageErrorListener?
An optional error callback for errors emitted when loading inactiveThumbImage.
finalinherited
overlayColor WidgetStateProperty<Color?>?
The color for the switch's Material.
finalinherited
padding EdgeInsetsGeometry?
The amount of space to surround the child inside the bounds of the Switch.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
splashRadius double?
The splash radius of the circular Material ink response.
finalinherited
thumbColor WidgetStateProperty<Color?>?
The color of this Switch's thumb.
finalinherited
thumbIcon WidgetStateProperty<Icon?>?
The icon to use on the thumb of this switch
finalinherited
trackColor WidgetStateProperty<Color?>?
The color of this Switch's track.
finalinherited
trackOutlineColor WidgetStateProperty<Color?>?
The outline color of this Switch's track.
finalinherited
trackOutlineWidth WidgetStateProperty<double?>?
The outline width of this Switch's track.
finalinherited
value bool
Whether this switch is on or off.
finalinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
inherited
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited