QsWidgetPlatform class abstract

qs_widget 插件的平台能力抽象接口。

Inheritance
  • Object
  • PlatformInterface
  • QsWidgetPlatform
Implementers

Constructors

QsWidgetPlatform()
创建平台接口实例,并绑定用于校验实现类的令牌。

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() Future<String?>
获取当前运行平台的版本信息。
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance QsWidgetPlatform
获取当前生效的平台实现。
getter/setter pair