QsImageType enum
图片资源类型。
Values
- asset → const QsImageType
-
Flutter 资源目录中的位图。
- svg → const QsImageType
-
Flutter 资源目录中的 SVG 图片。
- network → const QsImageType
-
通过网络地址加载的图片。
- file → const QsImageType
-
设备本地文件系统中的图片。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
QsImageType> - A constant List of the values in this enum, in order of their declaration.