MethodChannelQsWidget class
使用方法通道实现的 qs_widget 平台能力。
- Inheritance
-
- Object
- PlatformInterface
- QsWidgetPlatform
- MethodChannelQsWidget
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
与原生平台通信的方法通道。
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getPlatformVersion(
) → Future< String?> -
通过方法通道获取当前运行平台的版本信息。
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited